@@ -3,9 +3,9 @@ package com.sun.tools.javap.resources;
 public final class version extends java.util.ListResourceBundle {
     protected final Object[][] getContents() {
         return new Object[][] {
-            { "full", "16.0.1-internal+0-adhoc.root.jdk16u-jdk-16.0.1-ga" },
-            { "jdk", "16.0.1" },
-            { "release", "16.0.1-internal" },
+            { "full", "20.0.2-internal-adhoc.root.jdk20u-jdk-20.0.2-ga" },
+            { "jdk", "20.0.2" },
+            { "release", "20.0.2-internal" },
         };
     }
 }
